summaryrefslogtreecommitdiff
path: root/test/unit/node/node_white.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'test/unit/node/node_white.cpp')
-rw-r--r--test/unit/node/node_white.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/test/unit/node/node_white.cpp b/test/unit/node/node_white.cpp
index 651dd1990..d914c5dc2 100644
--- a/test/unit/node/node_white.cpp
+++ b/test/unit/node/node_white.cpp
@@ -9,9 +9,9 @@
** All rights reserved. See the file COPYING in the top-level source
** directory for licensing information.\endverbatim
**
** \brief White box testing of CVC4::Node.
**
** White box testing of CVC4::Node.
**/
#include <string>
@@ -19,7 +19,7 @@
#include "base/check.h"
#include "test_node.h"
-namespace CVC4 {
+namespace CVC5 {
using namespace kind;
using namespace expr;
@@ -79,4 +79,4 @@ TEST_F(TestNodeWhiteNode, iterators)
ASSERT_EQ(v[2], y);
}
} // namespace test
-} // namespace CVC4
+} // namespace CVC5
generated by cgit on debian on lair
contact matthew@masot.net with questions or feedback
@@ -9,9 +9,9 @@
** directory for licensing information.\endverbatim
**
- ** \brief White box testing of CVC4::Node.
+ ** \brief White box testing of CVC5::Node.
**
@@ -9,9 +9,9 @@
**
- ** White box testing of CVC4::Node.
+ ** White box testing of CVC5::Node.
**/
#include <string>